//OUT widgets.out
import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;
import java.util.Scanner;

public class Widgets
{
    private static final String INPUT_FILE_NAME = "widgets.csv";
    private static final String REPORT_NAME     = "widgets.out";
    
    private Scanner     in;
    private PrintWriter out;
    
    private String hdrState, hdrPlant, hdrDept, hdrEmpId, hdrName, hdrCount;
    
    private void doColumnHeaders()
    {
        String headerRecord = in.nextLine();
        Scanner headers = new Scanner(headerRecord);
        headers.useDelimiter(",");
        
        hdrState = headers.next();
        hdrPlant = headers.next();
        hdrDept  = headers.next();
        hdrEmpId = headers.next();
        hdrName  = headers.next();
        hdrCount = headers.next();
        
        out.printf("%s %s %s %s %s %s\n\n",
                   hdrState, hdrPlant, hdrDept, 
                   hdrEmpId, hdrCount, hdrName);
        headers.close();
    }
    
    private void doDetailRecords()
    {
        int state, plant, dept, id, count;
        String name;
        
        while (in.hasNextLine()) {
            String detailRecord = in.nextLine();
            Scanner detail = new Scanner(detailRecord);
            detail.useDelimiter(",");

            state = detail.nextInt();
            plant = detail.nextInt();
            dept  = detail.nextInt();
            id    = detail.nextInt();
            name  = detail.next();
            count = detail.nextInt();
            
            out.printf("%5d %5d %4d %5d %5d %s\n",
                       state, plant, dept, id, count, name);
            detail.close();
        }
    }
    
    private void generateReport()
    {
        doColumnHeaders();
        doDetailRecords();
    }
    
    private void initialize(String inputFileName, String outputFileName)
    {
        try {
            in  = new Scanner(new File(inputFileName));
            out = new PrintWriter(outputFileName);
            
            generateReport();
        }
        catch (FileNotFoundException ex) {
            System.out.println("*** ERROR: File not found: " + inputFileName);
        }
        finally {
            if (in != null) in.close();
            if (out != null) out.close();
        }
    }
    
    public static void main(String args[])
    {
        Widgets widgets = new Widgets();
        widgets.initialize(INPUT_FILE_NAME, REPORT_NAME);
    }
}
